@@ -63,7 +63,7 @@ class Freebox(IPlugin):
 					# séparation de rs['idx'], nombre   len(maliste)
 					lg=len(rs['idx'])		
 					log.msg(" lg  :  %s" % (lg))
-					for bar in range lg
+					for bar in range lg:
 ##				#	while i = rs['idx_sec']:
 ##						for i in rs['idx_sec']:
 ##								if rs['idx'][i - rang] == '|':
